# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-03-06 15:58
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='SocialAccount',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('provider', models.CharField(max_length=32)),
                ('uid', models.CharField(max_length=256)),
                ('access_token', models.TextField(blank=True, default='')),
                ('secret', models.TextField(blank=True, default='')),
                ('expires', models.DateTimeField(blank=True, null=True)),
                ('_data', models.TextField(blank=True, default='{}', help_text='Original token response from the OAuth provider.')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='social_accounts', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='socialaccount',
            unique_together=set([('uid', 'provider')]),
        ),
    ]
